@@ -2,7 +2,7 @@ import numpy as np
 import pandas as pd
 
 from .jscatter import Scatter, component_idx_to_name
-from .utils import to_ndc, get_default_norm
+from .utils import to_ndc, create_default_norm
 
 def test_component_idx_to_name():
     assert component_idx_to_name(2) == 'valueA'
@@ -20,8 +20,8 @@ def test_scatter_numpy():
     widget_data = np.asarray(widget.points)
 
     assert (500, 4) == widget_data.shape
-    assert np.allclose(to_ndc(x, get_default_norm()), widget_data[:,0])
-    assert np.allclose(to_ndc(y, get_default_norm()), widget_data[:,1])
+    assert np.allclose(to_ndc(x, create_default_norm()), widget_data[:,0])
+    assert np.allclose(to_ndc(y, create_default_norm()), widget_data[:,1])
     assert np.sum(widget_data[:,2:]) == 0
 
 def get_df():
@@ -53,8 +53,8 @@ def test_scatter_pandas():
     widget_data = np.asarray(widget.points)
 
     assert (500, 4) == np.asarray(widget.points).shape
-    assert np.allclose(to_ndc(df['a'].values, get_default_norm()), widget_data[:,0])
-    assert np.allclose(to_ndc(df['b'].values, get_default_norm()), widget_data[:,1])
+    assert np.allclose(to_ndc(df['a'].values, create_default_norm()), widget_data[:,0])
+    assert np.allclose(to_ndc(df['b'].values, create_default_norm()), widget_data[:,1])
 
 def test_scatter_point_encoding_updates():
     df = get_df()
